***************
cinq-auth-local
***************

Please open issues in the `Cloud-Inquisitor <https://github.com/RiotGames/cloud-inquisitor/issues/new?labels=cinq-auth-local>`_ repository

This code enables local authentication and authorisation for Cloud Inquisitor.
